/*
 * Elite - The New Kind, PalmOS port
 *
 * Reverse engineered from the BBC disk version of Elite.
 * Additional material by C.J.Pinder and T.Harbaum
 *
 * The original Elite code is (C) I.Bell & D.Braben 1984.
 * This version re-engineered in C by C.J.Pinder 1999-2001.
 *
 * email: <christian@newkind.co.uk>
 *
 * PalmOS port (c) 2002 by Till Harbaum <till@harbaum.org>
 *
 */
/*
  mkshipdata
*/

#include <stdio.h>
#include <math.h>

#include "shipdata.h"

/* ships:
  1  - missile    2  - coriolis    3  - esccaps     4  - alloy
  5  - cargo      6  - boulder     7  - asteroid    8  - rock
  9  - orbit      10 - transp      11 - cobra3a     12 - pythona
  13 - boa        14 - anacnda     15 - hermit      16 - viper
  17 - sidewnd    18 - mamba       19 - krait       20 - adder
  21 - gecko      22 - cobra1      23 - worm        24 - moray
  25 - cobra3b    26 - asp2        27 - pythonb     28 - ferdlce     
  29 - thargoid   30 - thargon     31 - constrct    32 - cougar
  33 - dodec
*/

#include "colors.h"

#ifdef NEW_SHIP_WOLF
const struct ship_data wolf_mki_data = {
  "Wolf MkI",          // name
  22,                  // num_points
  12, 0,               // num_faces, low_detail_faces
  0,                   // max loot
  0,                   // scoop_type
  9801,                // size
  15,                  // front_laser
  500,                 // bounty
  240,                 // energy
  39,                  // velocity
  6,                   // missiles
  11                   // laser_strength
};

const struct ship_data wolf_mkii_data = {
  "Wolf MkII",         // name
  28,                  // num_points
  19, 0,               // num_faces, low_detail_faces
  3,                   // max loot
  0,                   // scoop_type
  9025,                // size
  21,                  // front_laser
  0,                   // bounty
  150,                 // energy
  28,                  // velocity
  3,                   // missiles
  9                    // laser_strength
};
#endif

static const struct ship_point missile_point[17] = {
  {0, 0, 68, 31, 1, 0, 3, 2},
  {8, -8, 36, 31, 2, 1, 5, 4},
  {8, 8, 36, 31, 3, 2, 7, 4},
  {-8, 8, 36, 31, 3, 0, 7, 6},
  {-8, -8, 36, 31, 1, 0, 6, 5},
  {8, 8, -44, 31, 7, 4, 8, 8},
  {8, -8, -44, 31, 5, 4, 8, 8},
  {-8, -8, -44, 31, 6, 5, 8, 8},
  {-8, 8, -44, 31, 7, 6, 8, 8},
  {12, 12, -44, 8, 7, 4, 8, 8},
  {12, -12, -44, 8, 5, 4, 8, 8},
  {-12, -12, -44, 8, 6, 5, 8, 8},
  {-12, 12, -44, 8, 7, 6, 8, 8},
  {-8, 8, -12, 8, 7, 6, 7, 7},
  {-8, -8, -12, 8, 6, 5, 6, 6},
  {8, 8, -12, 8, 7, 4, 7, 7},
  {8, -8, -12, 8, 5, 4, 5, 5},
};

static const struct ship_data missile_data = {
  "Missile",
  17,
  17, 0,
  0,
  0,
  1600,
  0,
  0,
  2,  // energy
  44,
  0,
  0
};

const struct ship_point coriolis_point[16] = {
  {160, 0, 160, 31, 1, 0, 6, 2},
  {0, 160, 160, 31, 2, 0, 8, 3},
  {-160, 0, 160, 31, 3, 0, 7, 4},
  {0, -160, 160, 31, 1, 0, 5, 4},
  {160, -160, 0, 31, 5, 1, 10, 6},
  {160, 160, 0, 31, 6, 2, 11, 8},
  {-160, 160, 0, 31, 7, 3, 12, 8},
  {-160, -160, 0, 31, 5, 4, 9, 7},
  {160, 0, -160, 31, 10, 6, 13, 11},
  {0, 160, -160, 31, 11, 8, 13, 12},
  {-160, 0, -160, 31, 9, 7, 13, 12},
  {0, -160, -160, 31, 9, 5, 13, 10},
  {10, -30, 160, 30, 0, 0, 0, 0},
  {10, 30, 160, 30, 0, 0, 0, 0},
  {-10, 30, 160, 30, 0, 0, 0, 0},
  {-10, -30, 160, 30, 0, 0, 0, 0},
};

const struct ship_data coriolis_data = {
  "Coriolis Space Station",
  16,
  15, 0,
  0,
  0,
  25600,
  0,
  0,
  240,  // energy
  0,
  6,
  3
};



const struct ship_point esccaps_point[4] = {
  {-7, 0, 36, 31, 1, 2, 3, 3},
  {-7, -14, -12, 31, 0, 2, 3, 3},
  {-7, 14, -12, 31, 0, 1, 3, 3},
  {21, 0, 0, 31, 0, 1, 2, 2},
};

const struct ship_data esccaps_data = {
  "Escape Capsule",
  4,
  4, 0,
  0,
  2,
  256,
  0,
  0,
  17,  // energy
  8,
  0,
  0
};

const struct ship_point alloy_point[4] = {
  {-15, -22, -9, 31, 15, 15, 15, 15},
  {-15, 38, -9, 31, 15, 15, 15, 15},
  {19, 32, 11, 20, 15, 15, 15, 15},
  {10, -46, 6, 20, 15, 15, 15, 15},
};

const struct ship_data alloy_data = {
  "Alloy",
  4,
  2, 0,
  0,
  8,
  100,
  0,
  0,
  16,  // energy
  16,
  0,
  0
};



const struct ship_point cargo_point[10] = {
  {24, 16, 0, 31, 1, 0, 5, 5},
  {24, 5, 15, 31, 1, 0, 2, 2},
  {24, -13, 9, 31, 2, 0, 3, 3},
  {24, -13, -9, 31, 3, 0, 4, 4},
  {24, 5, -15, 31, 4, 0, 5, 5},
  {-24, 16, 0, 31, 5, 1, 6, 6},
  {-24, 5, 15, 31, 2, 1, 6, 6},
  {-24, -13, 9, 31, 3, 2, 6, 6},
  {-24, -13, -9, 31, 4, 3, 6, 6},
  {-24, 5, -15, 31, 5, 4, 6, 6},
};

const struct ship_data cargo_data = {
  "Cargo Canister",
  10,
  7, 0,
  0,
  0,
  400,
  0,
  0,
  17,  // energy
  15,
  0,
  0
};



const struct ship_point boulder_point[7] = {
  {-18, 37, -11, 31, 0, 1, 5, 9},
  {30, 7, 12, 31, 1, 2, 5, 6},
  {28, -7, -12, 31, 2, 3, 6, 7},
  {2, 0, -39, 31, 3, 4, 7, 8},
  {-28, 34, -30, 31, 0, 4, 8, 9},
  {5, -10, 13, 31, 15, 15, 15, 15},
  {20, 17, -30, 31, 15, 15, 15, 15},
};

const struct ship_data boulder_data = {
  "Boulder",
  7,
  10, 0,
  0,
  0,
  900,
  0,
  1,
  20,  // energy
  30,
  0,
  0
};



const struct ship_point asteroid_point[9] = {
  {0, 80, 0, 31, 15, 15, 15, 15},
  {-80, -10, 0, 31, 15, 15, 15, 15},
  {0, -80, 0, 31, 15, 15, 15, 15},
  {70, -40, 0, 31, 15, 15, 15, 15},
  {60, 50, 0, 31, 6, 5, 13, 12},
  {50, 0, 60, 31, 15, 15, 15, 15},
  {-40, 0, 70, 31, 1, 0, 3, 2},
  {0, 30, -75, 31, 15, 15, 15, 15},
  {0, -50, -60, 31, 9, 8, 11, 10},
};

const struct ship_data asteroid_data = {
  "Asteroid",
  9,
  14, 0,
  0,
  0,
  6400,
  0,
  5,
  60,  // energy
  30,
  0,
  0
};



const struct ship_point rock_point[4] = {
  {-24, -25, 16, 31, 1, 2, 3, 3},
  {0, 12, -10, 31, 0, 2, 3, 3},
  {11, -6, 2, 31, 0, 1, 3, 3},
  {12, 42, 7, 31, 0, 1, 2, 2},
};

const struct ship_data rock_data = {
  "Rock",
  4,
  4, 0,
  0,
  11,
  256,
  0,
  0,
  20,  // energy
  10,
  0,
  0
};



const struct ship_point orbit_point[19] = {
  {0, -17, 23, 31, 15, 15, 15, 15},
  {-17, 0, 23, 31, 15, 15, 15, 15},
  {0, 18, 23, 31, 15, 15, 15, 15},
  {18, 0, 23, 31, 15, 15, 15, 15},
  {-20, -20, -27, 31, 1, 2, 3, 9},
  {-20, 20, -27, 31, 3, 4, 5, 9},
  {20, 20, -27, 31, 5, 6, 7, 9},
  {20, -20, -27, 31, 1, 7, 8, 9},
  {5, 0, -27, 16, 9, 9, 9, 9},
  {0, -2, -27, 16, 9, 9, 9, 9},
  {-5, 0, -27, 9, 9, 9, 9, 9},
  {0, 3, -27, 9, 9, 9, 9, 9},
  {0, -9, 35, 16, 0, 10, 11, 12},
  {3, -1, 31, 7, 15, 15, 0, 2},
  {4, 11, 25, 8, 0, 1, 15, 4},
  {11, 4, 25, 8, 10, 1, 3, 15},
  {-3, -1, 31, 7, 6, 11, 2, 3},
  {-3, 11, 25, 8, 15, 8, 12, 0},
  {-10, 4, 25, 8, 4, 15, 1, 8},
};

const struct ship_data orbit_data = {
  "Orbit Shuttle",
  19,
  16, 0,
  15,
  0,
  2500,
  0,
  0,
  32,  // energy
  8,
  0,
  0
};



const struct ship_point transp_point[37] = {
  {0, 10, -26, 31, 0, 6, 7, 7},
  {-25, 4, -26, 31, 0, 1, 7, 7},
  {-28, -3, -26, 31, 0, 1, 2, 2},
  {-25, -8, -26, 31, 0, 2, 3, 3},
  {26, -8, -26, 31, 0, 3, 4, 4},
  {29, -3, -26, 31, 0, 4, 5, 5},
  {26, 4, -26, 31, 0, 5, 6, 6},
  {0, 6, 12, 19, 15, 15, 15, 15},
  {-30, -1, 12, 31, 1, 7, 8, 9},
  {-33, -8, 12, 31, 1, 2, 3, 9},
  {33, -8, 12, 31, 3, 4, 5, 10},
  {30, -1, 12, 31, 5, 6, 10, 11},
  {-11, -2, 30, 31, 8, 9, 12, 13},
  {-13, -8, 30, 31, 3, 9, 13, 13},
  {14, -8, 30, 31, 3, 10, 13, 13},
  {11, -2, 30, 31, 10, 11, 12, 13},
  {-5, 6, 2, 7, 7, 7, 7, 7},
  {-18, 3, 2, 7, 7, 7, 7, 7},
  {-5, 7, -7, 7, 7, 7, 7, 7},
  {-18, 4, -7, 7, 7, 7, 7, 7},
  {-11, 6, -14, 7, 7, 7, 7, 7},
  {-11, 5, -7, 7, 7, 7, 7, 7},
  {5, 7, -14, 7, 6, 6, 6, 6},
  {18, 4, -14, 7, 6, 6, 6, 6},
  {11, 5, -7, 7, 6, 6, 6, 6},
  {5, 6, -3, 7, 6, 6, 6, 6},
  {18, 3, -3, 7, 6, 6, 6, 6},
  {11, 4, 8, 7, 6, 6, 6, 6},
  {11, 5, -3, 7, 6, 6, 6, 6},
  {-16, -8, -13, 6, 3, 3, 3, 3},
  {-16, -8, 16, 6, 3, 3, 3, 3},
  {17, -8, -13, 6, 3, 3, 3, 3},
  {17, -8, 16, 6, 3, 3, 3, 3},
  {-13, -3, -26, 8, 0, 0, 0, 0},
  {13, -3, -26, 8, 0, 0, 0, 0},
  {9, 3, -26, 5, 0, 0, 0, 0},
  {-8, 3, -26, 5, 0, 0, 0, 0},
};

const struct ship_data transp_data = {
  "Transporter",
  37,
  23, 0,
  0,
  0,
  2500,
  12,
  0,
  32,
  10,
  0,
  0
};



const struct ship_point cobra3a_point[28] = {
  {32, 0, 76, 31, 15, 15, 15, 15},
  {-32, 0, 76, 31, 15, 15, 15, 15},
  {0, 26, 24, 31, 15, 15, 15, 15},
  {-120, -3, -8, 31, 7, 3, 10, 10},
  {120, -3, -8, 31, 8, 4, 12, 12},
  {-88, 16, -40, 31, 15, 15, 15, 15},
  {88, 16, -40, 31, 15, 15, 15, 15},
  {128, -8, -40, 31, 9, 8, 12, 12},
  {-128, -8, -40, 31, 9, 7, 10, 10},
  {0, 26, -40, 31, 6, 5, 9, 9},
  {-32, -24, -40, 31, 10, 9, 11, 11},
  {32, -24, -40, 31, 11, 9, 12, 12},
  {-36, 8, -40, 20, 9, 9, 9, 9},
  {-8, 12, -40, 20, 9, 9, 9, 9},
  {8, 12, -40, 20, 9, 9, 9, 9},
  {36, 8, -40, 20, 9, 9, 9, 9},
  {36, -12, -40, 20, 9, 9, 9, 9},
  {8, -16, -40, 20, 9, 9, 9, 9},
  {-8, -16, -40, 20, 9, 9, 9, 9},
  {-36, -12, -40, 20, 9, 9, 9, 9},
  {0, 0, 76, 6, 11, 0, 11, 11},
  {0, 0, 90, 31, 11, 0, 11, 11},
  {-80, -6, -40, 8, 9, 9, 9, 9},
  {-80, 6, -40, 8, 9, 9, 9, 9},
  {-88, 0, -40, 6, 9, 9, 9, 9},
  {80, 6, -40, 8, 9, 9, 9, 9},
  {88, 0, -40, 6, 9, 9, 9, 9},
  {80, -6, -40, 8, 9, 9, 9, 9},
};

const struct ship_data cobra3a_data = {
  "Cobra MkIII",
  28,
  19, 0,
  3,
  0,
  9025,
  21,
  0,
  150,
  28,
  3,
  9
};



const struct ship_point pythona_point[11] = {
  {0, 0, 224, 31, 1, 0, 3, 2},
  {0, 48, 48, 31, 1, 0, 5, 4},
  {96, 0, -16, 31, 15, 15, 15, 15},
  {-96, 0, -16, 31, 15, 15, 15, 15},
  {0, 48, -32, 31, 5, 4, 9, 8},
  {0, 24, -112, 31, 8, 9, 12, 12},
  {-48, 0, -112, 31, 11, 8, 12, 12},
  {48, 0, -112, 31, 10, 9, 12, 12},
  {0, -48, 48, 31, 3, 2, 7, 6},
  {0, -48, -32, 31, 7, 6, 11, 10},
  {0, -24, -112, 31, 11, 10, 12, 12},
};

const struct ship_data pythona_data = {
  "Python",
  11,
  13, 0,
  5,
  0,
  6400,
  0,
  0,
  250,
  20,
  3,
  13
};



const struct ship_point boa_point[13] = {
  {0, 0, 93, 31, 15, 15, 15, 15},
  {0, 40, -87, 24, 0, 2, 3, 3},
  {38, -25, -99, 24, 0, 1, 4, 4},
  {-38, -25, -99, 24, 1, 2, 5, 5},
  {-38, 40, -59, 31, 2, 3, 6, 9},
  {38, 40, -59, 31, 0, 3, 6, 11},
  {62, 0, -67, 31, 0, 4, 8, 11},
  {24, -65, -79, 31, 1, 4, 8, 10},
  {-24, -65, -79, 31, 1, 5, 7, 10},
  {-62, 0, -67, 31, 2, 5, 7, 9},
  {0, 7, -107, 22, 0, 2, 10, 10},
  {13, -9, -107, 22, 0, 1, 10, 10},
  {-13, -9, -107, 22, 1, 2, 12, 12},
};

const struct ship_data boa_data = {
  "Boa",
  13,
  13, 0,
  5,
  0,
  4900,
  0,
  0,
  250,
  24,
  4,
  14
};



const struct ship_point anacnda_point[15] = {
  {0, 7, -58, 30, 0, 1, 5, 5},
  {-43, -13, -37, 30, 0, 1, 2, 2},
  {-26, -47, -3, 30, 0, 2, 3, 3},
  {26, -47, -3, 30, 0, 3, 4, 4},
  {43, -13, -37, 30, 0, 4, 5, 5},
  {0, 48, -49, 30, 1, 5, 6, 6},
  {-69, 15, -15, 30, 1, 2, 7, 7},
  {-43, -39, 40, 31, 2, 3, 8, 8},
  {43, -39, 40, 31, 3, 4, 9, 9},
  {69, 15, -15, 30, 4, 5, 10, 10},
  {-43, 53, -23, 31, 15, 15, 15, 15},
  {-69, -1, 32, 31, 2, 7, 8, 8},
  {0, 0, 254, 31, 15, 15, 15, 15},
  {69, -1, 32, 31, 4, 9, 10, 10},
  {43, 53, -23, 31, 15, 15, 15, 15},
};

const struct ship_data anacnda_data = {
  "Anaconda",
  15,
  12, 0,
  7,
  0,
  10000,
  12,
  0,
  252,
  14,
  7,
  31
};



const struct ship_point hermit_point[9] = {
  {0, 80, 0, 31, 15, 15, 15, 15},
  {-80, -10, 0, 31, 15, 15, 15, 15},
  {0, -80, 0, 31, 15, 15, 15, 15},
  {70, -40, 0, 31, 15, 15, 15, 15},
  {60, 50, 0, 31, 6, 5, 13, 12},
  {50, 0, 60, 31, 15, 15, 15, 15},
  {-40, 0, 70, 31, 1, 0, 3, 2},
  {0, 30, -75, 31, 15, 15, 15, 15},
  {0, -50, -60, 31, 9, 8, 11, 10},
};

const struct ship_data hermit_data = {
  "Rock Hermit",
  9,
  14, 0,
  7,
  0,
  6400,
  0,
  0,
  180,
  30,
  2,
  1
};



const struct ship_point viper_point[15] = {
  {0, 0, 72, 31, 2, 1, 4, 3},
  {0, 16, 24, 30, 1, 0, 2, 2},
  {0, -16, 24, 30, 4, 3, 5, 5},
  {48, 0, -24, 31, 4, 2, 6, 6},
  {-48, 0, -24, 31, 3, 1, 6, 6},
  {24, -16, -24, 30, 5, 4, 6, 6},
  {-24, -16, -24, 30, 3, 5, 6, 6},
  {24, 16, -24, 31, 2, 0, 6, 6},
  {-24, 16, -24, 31, 1, 0, 6, 6},
  {-32, 0, -24, 19, 6, 6, 6, 6},
  {32, 0, -24, 19, 6, 6, 6, 6},
  {8, 8, -24, 19, 6, 6, 6, 6},
  {-8, 8, -24, 19, 6, 6, 6, 6},
  {-8, -8, -24, 18, 6, 6, 6, 6},
  {8, -8, -24, 18, 6, 6, 6, 6},
};

const struct ship_data viper_data = {
  "Viper",
  15,
  9, 0,
  0,
  0,
  5625,
  0,
  0,
  140,
  32,
  1,
  8
};



const struct ship_point sidewnd_point[10] = {
  {-32, 0, 36, 31, 1, 0, 5, 4},
  {32, 0, 36, 31, 2, 0, 6, 5},
  {64, 0, -28, 31, 3, 2, 6, 6},
  {-64, 0, -28, 31, 3, 1, 4, 4},
  {0, 16, -28, 31, 1, 0, 3, 2},
  {0, -16, -28, 31, 4, 3, 6, 5},
  {-12, 6, -28, 15, 3, 3, 3, 3},
  {12, 6, -28, 15, 3, 3, 3, 3},
  {12, -6, -28, 12, 3, 3, 3, 3},
  {-12, -6, -28, 12, 3, 3, 3, 3},
};

const struct ship_data sidewnd_data = {
  "Sidewinder",
  10,
  8, 0,
  0,
  0,
  4225,
  0,
  50,
  70,
  37,
  0,
  8
};



const struct ship_point mamba_point[25] = {
  {0, 0, 64, 31, 1, 0, 3, 2},
  {-64, -8, -32, 31, 2, 0, 4, 4},
  {-32, 8, -32, 30, 2, 1, 4, 4},
  {32, 8, -32, 30, 3, 1, 4, 4},
  {64, -8, -32, 31, 3, 0, 4, 4},
  {-4, 4, 16, 14, 1, 1, 1, 1},
  {4, 4, 16, 14, 1, 1, 1, 1},
  {8, 3, 28, 13, 1, 1, 1, 1},
  {-8, 3, 28, 13, 1, 1, 1, 1},
  {-20, -4, 16, 20, 0, 0, 0, 0},
  {20, -4, 16, 20, 0, 0, 0, 0},
  {-24, -7, -20, 20, 0, 0, 0, 0},
  {-16, -7, -20, 16, 0, 0, 0, 0},
  {16, -7, -20, 16, 0, 0, 0, 0},
  {24, -7, -20, 20, 0, 0, 0, 0},
  {-8, 4, -32, 13, 4, 4, 4, 4},
  {8, 4, -32, 13, 4, 4, 4, 4},
  {8, -4, -32, 14, 4, 4, 4, 4},
  {-8, -4, -32, 14, 4, 4, 4, 4},
  {-32, 4, -32, 7, 4, 4, 4, 4},
  {32, 4, -32, 7, 4, 4, 4, 4},
  {36, -4, -32, 7, 4, 4, 4, 4},
  {-36, -4, -32, 7, 4, 4, 4, 4},
  {-38, 0, -32, 5, 4, 4, 4, 4},
  {38, 0, -32, 5, 4, 4, 4, 4},
};

const struct ship_data mamba_data = {
  "Mamba",
  25,
  11, 0,
  1,
  0,
  4900,
  0,
  150,
  90,
  30,
  2,
  9
};



const struct ship_point krait_point[17] = {
  {0, 0, 96, 31, 0, 1, 2, 3},
  {0, 18, -48, 31, 0, 3, 4, 5},
  {0, -18, -48, 31, 1, 2, 4, 5},
  {90, 0, -3, 31, 0, 1, 4, 4},
  {-90, 0, -3, 31, 2, 3, 5, 5},
  {90, 0, 87, 30, 0, 1, 1, 1},
  {-90, 0, 87, 30, 2, 3, 3, 3},
  {0, 5, 53, 9, 0, 0, 3, 3},
  {0, 7, 38, 6, 0, 0, 3, 3},
  {-18, 7, 19, 9, 3, 3, 3, 3},
  {18, 7, 19, 9, 0, 0, 0, 0},
  {18, 11, -39, 8, 4, 4, 4, 4},
  {18, -11, -39, 8, 4, 4, 4, 4},
  {36, 0, -30, 8, 4, 4, 4, 4},
  {-18, 11, -39, 8, 5, 5, 5, 5},
  {-18, -11, -39, 8, 5, 5, 5, 5},
  {-36, 0, -30, 8, 5, 5, 5, 5},
};

const struct ship_data krait_data = {
  "Krait",
  17,
  14, 0,
  1,
  0,
  3600,
  0,
  100,
  80,
  30,
  0,
  8
};



const struct ship_point adder_point[18] = {
  {-18, 0, 40, 31, 0, 1, 11, 12},
  {18, 0, 40, 31, 0, 1, 2, 3},
  {30, 0, -24, 31, 2, 3, 4, 5},
  {30, 0, -40, 31, 4, 5, 6, 6},
  {18, -7, -40, 31, 5, 6, 7, 14},
  {-18, -7, -40, 31, 7, 8, 10, 14},
  {-30, 0, -40, 31, 8, 9, 10, 10},
  {-30, 0, -24, 31, 9, 10, 11, 12},
  {-18, 7, -40, 31, 7, 8, 9, 13},
  {18, 7, -40, 31, 4, 6, 7, 13},
  {-18, 7, 13, 31, 0, 9, 11, 13},
  {18, 7, 13, 31, 0, 2, 4, 13},
  {-18, -7, 13, 31, 1, 10, 12, 14},
  {18, -7, 13, 31, 1, 3, 5, 14},
  {-11, 3, 29, 5, 0, 0, 0, 0},
  {11, 3, 29, 5, 0, 0, 0, 0},
  {11, 4, 24, 4, 0, 0, 0, 0},
  {-11, 4, 24, 4, 0, 0, 0, 0},
};

const struct ship_data adder_data = {
  "Adder",
  18,
  14, 0,
  0,
  0,
  2500,
  0,
  40,
  85,
  24,
  0,
  8
};



const struct ship_point gecko_point[12] = {
  {-10, -4, 47, 31, 0, 3, 4, 5},
  {10, -4, 47, 31, 0, 1, 2, 3},
  {-16, 8, -23, 31, 0, 5, 6, 7},
  {16, 8, -23, 31, 0, 1, 7, 8},
  {-66, 0, -3, 31, 4, 5, 6, 6},
  {66, 0, -3, 31, 1, 2, 8, 8},
  {-20, -14, -23, 31, 3, 4, 6, 7},
  {20, -14, -23, 31, 2, 3, 7, 8},
  {-8, -6, 33, 16, 3, 3, 3, 3},
  {8, -6, 33, 17, 3, 3, 3, 3},
  {-8, -13, -16, 16, 3, 3, 3, 3},
  {8, -13, -16, 17, 3, 3, 3, 3},
};

const struct ship_data gecko_data = {
  "Gecko",
  12,
  11, 0,
  0,
  0,
  9801,
  0,
  55,
  70,
  30,
  0,
  8
};



const struct ship_point cobra1_point[11] = {
  {-18, -1, 50, 31, 0, 1, 2, 3},
  {18, -1, 50, 31, 0, 1, 4, 5},
  {-66, 0, 7, 31, 2, 3, 8, 8},
  {66, 0, 7, 31, 4, 5, 9, 9},
  {-32, 12, -38, 31, 2, 6, 7, 8},
  {32, 12, -38, 31, 4, 6, 7, 9},
  {-54, -12, -38, 31, 1, 3, 7, 8},
  {54, -12, -38, 31, 1, 5, 7, 9},
  {0, 12, -6, 20, 0, 2, 4, 6},
  {0, -1, 50, 2, 0, 1, 1, 1},
  {0, -1, 60, 31, 0, 1, 1, 1},
};

const struct ship_data cobra1_data = {
  "Cobra MkI",
  11,
  12, 0,
  3,
  0,
  9801,
  10,
  75,
  90,
  26,
  2,
  9
};



const struct ship_point worm_point[10] = {
  {10, -10, 35, 31, 0, 2, 7, 7},
  {-10, -10, 35, 31, 0, 3, 7, 7},
  {5, 6, 15, 31, 0, 1, 2, 4},
  {-5, 6, 15, 31, 0, 1, 3, 5},
  {15, -10, 25, 31, 2, 4, 7, 7},
  {-15, -10, 25, 31, 3, 5, 7, 7},
  {26, -10, -25, 31, 4, 6, 7, 7},
  {-26, -10, -25, 31, 5, 6, 7, 7},
  {8, 14, -25, 31, 1, 4, 6, 6},
  {-8, 14, -25, 31, 1, 5, 6, 6},
};

const struct ship_data worm_data = {
  "Worm",
  10,
  8, 0,
  0,
  0,
  9801,
  0,
  0,
  30,
  23,
  0,
  4
};



const struct ship_point cobra3b_point[28] = {
  {32, 0, 76, 31, 15, 15, 15, 15},
  {-32, 0, 76, 31, 15, 15, 15, 15},
  {0, 26, 24, 31, 15, 15, 15, 15},
  {-120, -3, -8, 31, 7, 3, 10, 10},
  {120, -3, -8, 31, 8, 4, 12, 12},
  {-88, 16, -40, 31, 15, 15, 15, 15},
  {88, 16, -40, 31, 15, 15, 15, 15},
  {128, -8, -40, 31, 9, 8, 12, 12},
  {-128, -8, -40, 31, 9, 7, 10, 10},
  {0, 26, -40, 31, 6, 5, 9, 9},
  {-32, -24, -40, 31, 10, 9, 11, 11},
  {32, -24, -40, 31, 11, 9, 12, 12},
  {-36, 8, -40, 20, 9, 9, 9, 9},
  {-8, 12, -40, 20, 9, 9, 9, 9},
  {8, 12, -40, 20, 9, 9, 9, 9},
  {36, 8, -40, 20, 9, 9, 9, 9},
  {36, -12, -40, 20, 9, 9, 9, 9},
  {8, -16, -40, 20, 9, 9, 9, 9},
  {-8, -16, -40, 20, 9, 9, 9, 9},
  {-36, -12, -40, 20, 9, 9, 9, 9},
  {0, 0, 76, 6, 11, 0, 11, 11},
  {0, 0, 90, 31, 11, 0, 11, 11},
  {-80, -6, -40, 8, 9, 9, 9, 9},
  {-80, 6, -40, 8, 9, 9, 9, 9},
  {-88, 0, -40, 6, 9, 9, 9, 9},
  {80, 6, -40, 8, 9, 9, 9, 9},
  {88, 0, -40, 6, 9, 9, 9, 9},
  {80, -6, -40, 8, 9, 9, 9, 9},
};

const struct ship_data cobra3b_data = {
  "Cobra MkIII b",
  28,
  19, 0,
  1,
  0,
  9025,
  21,
  175,
  150,
  28,
  2,
  9
};



const struct ship_point asp2_point[19] = {
  {0, -18, 0, 22, 0, 1, 2, 2},
  {0, -9, -45, 31, 1, 2, 11, 11},
  {43, 0, -45, 31, 1, 6, 11, 11},
  {69, -3, 0, 31, 1, 6, 7, 9},
  {43, -14, 28, 31, 0, 1, 7, 7},
  {-43, 0, -45, 31, 2, 5, 11, 11},
  {-69, -3, 0, 31, 2, 5, 8, 10},
  {-43, -14, 28, 31, 0, 2, 8, 8},
  {26, -7, 73, 31, 0, 4, 7, 9},
  {-26, -7, 73, 31, 0, 4, 8, 10},
  {43, 14, 28, 31, 3, 4, 6, 9},
  {-43, 14, 28, 31, 3, 4, 5, 10},
  {0, 9, -45, 31, 3, 5, 6, 11},
  {-17, 0, -45, 10, 11, 11, 11, 11},
  {17, 0, -45, 9, 11, 11, 11, 11},
  {0, -4, -45, 10, 11, 11, 11, 11},
  {0, 4, -45, 8, 11, 11, 11, 11},
  {0, -7, 73, 10, 0, 4, 0, 4},
  {0, -7, 83, 10, 0, 4, 0, 4},
};

const struct ship_data asp2_data = {
  "Asp MkII",
  19,
  15, 0,
  0,
  0,
  3600,
  8,
  200,
  150,
  40,
  1,
  20
};



const struct ship_point pythonb_point[11] = {
  {0, 0, 224, 31, 1, 0, 3, 2},
  {0, 48, 48, 31, 1, 0, 5, 4},
  {96, 0, -16, 31, 15, 15, 15, 15},
  {-96, 0, -16, 31, 15, 15, 15, 15},
  {0, 48, -32, 31, 5, 4, 9, 8},
  {0, 24, -112, 31, 8, 9, 12, 12},
  {-48, 0, -112, 31, 11, 8, 12, 12},
  {48, 0, -112, 31, 10, 9, 12, 12},
  {0, -48, 48, 31, 3, 2, 7, 6},
  {0, -48, -32, 31, 7, 6, 11, 10},
  {0, -24, -112, 31, 11, 10, 12, 12},
};

const struct ship_data pythonb_data = {
  "Python b",
  11,
  13, 0,
  2,
  0,
  6400,
  0,
  200,
  250,
  20,
  3,
  13
};



const struct ship_point ferdlce_point[19] = {
  {0, -14, 108, 31, 0, 1, 5, 9},
  {-40, -14, -4, 31, 1, 2, 9, 9},
  {-12, -14, -52, 31, 2, 3, 9, 9},
  {12, -14, -52, 31, 3, 4, 9, 9},
  {40, -14, -4, 31, 4, 5, 9, 9},
  {-40, 14, -4, 28, 0, 1, 2, 6},
  {-12, 2, -52, 28, 2, 3, 6, 7},
  {12, 2, -52, 28, 3, 4, 7, 8},
  {40, 14, -4, 28, 0, 4, 5, 8},
  {0, 18, -20, 15, 0, 6, 7, 8},
  {-3, -11, 97, 11, 0, 0, 0, 0},
  {-26, 8, 18, 9, 0, 0, 0, 0},
  {-16, 14, -4, 11, 0, 0, 0, 0},
  {3, -11, 97, 11, 0, 0, 0, 0},
  {26, 8, 18, 9, 0, 0, 0, 0},
  {16, 14, -4, 11, 0, 0, 0, 0},
  {0, -14, -20, 12, 9, 9, 9, 9},
  {-14, -14, 44, 12, 9, 9, 9, 9},
  {14, -14, 44, 12, 9, 9, 9, 9},
};

const struct ship_data ferdlce_data = {
  "Fer-de-Lance",
  19,
  13, 0,
  0,
  0,
  1600,
  0,
  0,
  160,
  30,
  2,
  9
};



const struct ship_point moray_point[14] = {
  {15, 0, 65, 31, 0, 2, 7, 8},
  {-15, 0, 65, 31, 0, 1, 6, 7},
  {0, 18, -40, 17, 15, 15, 15, 15},
  {-60, 0, 0, 31, 1, 3, 6, 6},
  {60, 0, 0, 31, 2, 5, 8, 8},
  {30, -27, -10, 24, 4, 5, 7, 8},
  {-30, -27, -10, 24, 3, 4, 6, 7},
  {-9, -4, -25, 7, 4, 4, 4, 4},
  {9, -4, -25, 7, 4, 4, 4, 4},
  {0, -18, -16, 7, 4, 4, 4, 4},
  {13, 3, 49, 5, 0, 0, 0, 0},
  {6, 0, 65, 5, 0, 0, 0, 0},
  {-13, 3, 49, 5, 0, 0, 0, 0},
  {-6, 0, 65, 5, 0, 0, 0, 0},
};

const struct ship_data moray_data = {
  "Moray Star Boat",
  14,
  12, 0,
  1,
  0,
  900,
  0,
  50,
  100,
  25,
  0,
  8
};

const struct ship_point thargoid_point[22] = {
  /* top eight points */
  {32, -48, 48, 31, 4, 0, 8, 8},	// 0
  {32, -68, 0, 31, 1, 0, 4, 4},	// 1
  {32, -48, -48, 31, 2, 1, 4, 4},	// 2
  {32, 0, -68, 31, 3, 2, 4, 4},	// 3
  {32, 48, -48, 31, 4, 3, 5, 5},	// 4
  {32, 68, 0, 31, 5, 4, 6, 6},	// 5
  {32, 48, 48, 31, 6, 4, 7, 7},	// 6
  {32, 0, 68, 31, 7, 4, 8, 8},	// 7

  /* bottom eight points */
  {-24, -116, 116, 31, 8, 0, 9, 9},	// 8
  {-24, -164, 0, 31, 1, 0, 9, 9},	// 9
  {-24, -116, -116, 31, 2, 1, 9, 9},	// 10
  {-24, 0, -164, 31, 3, 2, 9, 9},	// 11
  {-24, 116, -116, 31, 5, 3, 9, 9},	// 12
  {-24, 164, 0, 31, 6, 5, 9, 9},	// 13
  {-24, 116, 116, 31, 7, 6, 9, 9},	// 14
  {-24, 0, 164, 31, 8, 7, 9, 9},	// 15

  /* six points for engine triangles */
  {-24, 64, 80, 30, 9, 9, 9, 9},	// 16
  {-24, 64, -80, 30, 9, 9, 9, 9},	// 17
  {-24, 40, 0, 30, 9, 9, 9, 9},	// 18

  {-24, -64, -80, 30, 9, 9, 9, 9},	// 19
  {-24, -64, 80, 30, 9, 9, 9, 9},	// 20
  {-24, -40, 0, 30, 9, 9, 9, 9},	// 21
};

const struct ship_data thargoid_data = {
  "Thargoid",
  22,
  12, 0,
  0,
  0,
  9801,
  15,
  500,
  240,
  39,
  6,
  11
};

const struct ship_point thargon_point[10] = {
  {-9, 0, 40, 31, 0, 1, 5, 5},
  {-9, -38, 12, 31, 0, 1, 2, 2},
  {-9, -24, -32, 31, 0, 2, 3, 3},
  {-9, 24, -32, 31, 0, 3, 4, 4},
  {-9, 38, 12, 31, 0, 4, 5, 5},
  {9, 0, -8, 31, 1, 5, 6, 6},
  {9, -10, -15, 31, 1, 2, 6, 6},
  {9, -6, -26, 31, 2, 3, 6, 6},
  {9, 6, -26, 31, 3, 4, 6, 6},
  {9, 10, -15, 31, 4, 5, 6, 6},
};

const struct ship_data thargon_data = {
  "Thargon",
  10,
  7, 0,
  0,
  15,
  1600,
  0,
  50,
  20,
  30,
  0,
  8
};



const struct ship_point constrct_point[17] = {
  {20, -7, 80, 31, 0, 2, 9, 9},
  {-20, -7, 80, 31, 0, 1, 9, 9},
  {-54, -7, 40, 31, 1, 4, 9, 9},
  {-54, -7, -40, 31, 4, 5, 8, 9},
  {-20, 13, -40, 31, 5, 6, 8, 8},
  {20, 13, -40, 31, 6, 7, 8, 8},
  {54, -7, -40, 31, 3, 7, 8, 9},
  {54, -7, 40, 31, 2, 3, 9, 9},
  {20, 13, 5, 31, 15, 15, 15, 15},
  {-20, 13, 5, 31, 15, 15, 15, 15},
  {20, -7, 62, 18, 9, 9, 9, 9},
  {-20, -7, 62, 18, 9, 9, 9, 9},
  {25, -7, -25, 18, 9, 9, 9, 9},
  {-25, -7, -25, 18, 9, 9, 9, 9},
  {15, -7, -15, 10, 9, 9, 9, 9},
  {-15, -7, -15, 10, 9, 9, 9, 9},
  {0, -7, 0, 0, 9, 15, 0, 1},
};

const struct ship_data constrct_data = {
  "Constrictor",
  17,
  12, 0,
  3,
  0,
  4225,
  0,
  0,
  252,
  36,
  4,
  26
};



const struct ship_point cougar_point[19] = {
  {0, 5, 67, 31, 0, 2, 4, 4},
  {-20, 0, 40, 31, 0, 1, 2, 2},
  {-40, 0, -40, 31, 0, 1, 5, 5},
  {0, 14, -40, 30, 0, 4, 5, 5},
  {0, -14, -40, 30, 1, 2, 3, 5},
  {20, 0, 40, 31, 2, 3, 4, 4},
  {40, 0, -40, 31, 3, 4, 5, 5},
  {-36, 0, 56, 31, 0, 1, 1, 1},
  {-60, 0, -20, 31, 0, 1, 1, 1},
  {36, 0, 56, 31, 3, 4, 4, 4},
  {60, 0, -20, 31, 3, 4, 4, 4},
  {0, 7, 35, 18, 0, 0, 4, 4},
  {0, 8, 25, 20, 0, 0, 4, 4},
  {-12, 2, 45, 20, 0, 0, 0, 0},
  {12, 2, 45, 20, 4, 4, 4, 4},
  {-10, 6, -40, 20, 5, 5, 5, 5},	// 15
  {-10, -6, -40, 20, 5, 5, 5, 5},	// 16
  {10, -6, -40, 20, 5, 5, 5, 5},	// 17
  {10, 6, -40, 20, 5, 5, 5, 5},	// 18
};

const struct ship_data cougar_data = {
  "Cougar",
  19,
  13, 0,
  3,
  0,
  4900,
  0,
  0,
  252,
  40,
  4,
  26
};



const struct ship_point dodec_point[24] = {
  {0, 150, 196, 31, 0, 1, 5, 5},
  {143, 46, 196, 31, 0, 1, 2, 2},
  {88, -121, 196, 31, 0, 2, 3, 3},
  {-88, -121, 196, 31, 0, 3, 4, 4},
  {-143, 46, 196, 31, 0, 4, 5, 5},
  {0, 243, 46, 31, 1, 5, 6, 6},
  {231, 75, 46, 31, 1, 2, 7, 7},
  {143, -196, 46, 31, 2, 3, 8, 8},
  {-143, -196, 46, 31, 3, 4, 9, 9},
  {-231, 75, 46, 31, 4, 5, 10, 10},
  {143, 196, -46, 31, 1, 6, 7, 7},
  {231, -75, -46, 31, 2, 7, 8, 8},
  {0, -243, -46, 31, 3, 8, 9, 9},
  {-231, -75, -46, 31, 4, 9, 10, 10},
  {-143, 196, -46, 31, 5, 6, 10, 10},
  {88, 121, -196, 31, 6, 7, 11, 11},
  {143, -46, -196, 31, 7, 8, 11, 11},
  {0, -150, -196, 31, 8, 9, 11, 11},
  {-143, -46, -196, 31, 9, 10, 11, 11},
  {-88, 121, -196, 31, 6, 10, 11, 11},
  {-16, 32, 196, 30, 0, 0, 0, 0},
  {-16, -32, 196, 30, 0, 0, 0, 0},
  {16, 32, 196, 23, 0, 0, 0, 0},
  {16, -32, 196, 23, 0, 0, 0, 0},
};

const struct ship_data dodec_data = {
  "Dodec Space Station",
  24,
  13, 0,
  0,
  0,
  32400,
  0,
  0,
  240,
  0,
  0,
  0
};

const struct ship_face missile_face[] = {
  //fins red
  {TD_COL_RED, 0x20, 0x00, 0x00, 3, 5, 9, 15, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, 0x20, 0x00, 3, 15, 9, 5, 0, 0, 0, 0, 0},

  {TD_COL_RED, -0x20, 0x00, 0x00, 3, 8, 12, 13, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, 0x20, 0x00, 3, 13, 12, 8, 0, 0, 0, 0, 0},

  {TD_COL_RED, -0x20, 0x00, 0x00, 3, 7, 11, 14, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, -0x20, 0x00, 3, 14, 11, 7, 0, 0, 0, 0, 0},

  {TD_COL_RED, 0x20, 0x00, 0x00, 3, 6, 10, 16, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, -0x20, 0x00, 3, 16, 10, 6, 0, 0, 0, 0, 0},

  //nose cone red/dark red
  {TD_COL_DARK_RED, -0x40, 0x00, 0x10, 3, 0, 3, 4, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, -0x40, 0x10, 3, 0, 4, 1, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x40, 0x00, 0x10, 3, 0, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x00, 0x40, 0x10, 3, 0, 2, 3, 0, 0, 0, 0, 0},

  //main body
  {TD_COL_GREY_3, 0x20, 0x00, 0x00, 4, 6, 5, 2, 1, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x20, 0x00, 4, 5, 8, 3, 2, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x20, 0x00, 0x00, 4, 8, 7, 4, 3, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, -0x20, 0x00, 4, 7, 6, 1, 4, 0, 0, 0, 0},

  //bottom
  {TD_COL_ENGINE, 0x00, 0x00, -0xB0, 4, 5, 6, 7, 8, 0, 0, 0, 0},
};

const struct ship_face coriolis_face[] = {
  {TD_COL_GREY_3, 0x6B, -0x6B, 0x6B, 3, 4, 0, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x6B, 0x6B, 0x6B, 3, 0, 5, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x6B, 0x6B, 0x6B, 3, 1, 6, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x6B, -0x6B, 0x6B, 3, 2, 7, 3, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, -0xA0, 0x00, 4, 4, 3, 7, 11, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0xA0, 0x00, 0x00, 4, 8, 5, 0, 4, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0xA0, 0x00, 0x00, 4, 10, 7, 2, 6, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x00, 0xA0, 0x00, 4, 1, 5, 9, 6, 0, 0, 0, 0},

  {TD_COL_GREY_3, -0x6B, -0x6B, -0x6B, 3, 11, 7, 10, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x6B, -0x6B, -0x6B, 3, 11, 8, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x6B, 0x6B, -0x6B, 3, 9, 5, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x6B, 0x6B, -0x6B, 3, 10, 6, 9, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, 0x00, -0xA0, 4, 11, 10, 9, 8, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x00, 0xA0, 4, 0, 1, 2, 3, 0, 0, 0, 0},

  {TD_COL_BLACK, 0x00, 0x00, 0xA0, 4, 15, 12, 13, 14, 0, 0, 0, 0},
};


const struct ship_face esccaps_face[] = {
  {TD_COL_ENGINE, 0x34, 0x00, -0x7A, 3, 3, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, 0x27, 0x67, 0x1E, 3, 0, 3, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_2, 0x27, -0x67, 0x1E, 3, 0, 1, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_3, -0x70, 0x00, 0x00, 3, 0, 2, 1, 0, 0, 0, 0, 0},
};


const struct ship_face alloy_face[] = {
  {TD_COL_GREY_1, 0x00, 0x00, 0x00, 4, 0, 1, 2, 3, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, 0x00, 0x00, 4, 3, 2, 1, 0, 0, 0, 0, 0},
};

const struct ship_face cargo_face[] = {
  {TD_COL_GREY_4, 0x60, 0x00, 0x00, 5, 4, 0, 1, 2, 3, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, 0x29, 0x1E, 4, 5, 6, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, -0x12, 0x30, 4, 6, 7, 2, 1, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, -0x33, 0x00, 4, 7, 8, 3, 2, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, -0x12, -0x30, 4, 8, 9, 4, 3, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, 0x29, -0x1E, 4, 9, 5, 0, 4, 0, 0, 0, 0},

  {TD_COL_GREY_4, -0x60, 0x00, 0x00, 5, 8, 7, 6, 5, 9, 0, 0, 0},
};


const struct ship_face boulder_face[] = {
  {TD_COL_GREY_3, -0x0F, -0x03, 0x08, 3, 0, 4, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x07, 0x0C, 0x1E, 3, 0, 5, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x20, -0x2F, 0x18, 3, 1, 5, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x03, -0x27, -0x07, 3, 2, 5, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x05, -0x04, -0x01, 3, 3, 5, 4, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x31, 0x54, 0x08, 3, 1, 6, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x70, 0x15, -0x15, 3, 2, 6, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x4C, -0x23, -0x52, 3, 3, 6, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x16, 0x38, -0x89, 3, 4, 6, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x28, 0x6E, -0x26, 3, 6, 4, 0, 0, 0, 0, 0, 0},
};


const struct ship_face asteroid_face[] = {
  {TD_COL_GREY_3, 0x09, 0x42, 0x51, 3, 5, 0, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x09, -0x42, 0x51, 3, 2, 5, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x48, 0x40, 0x1F, 3, 6, 0, 1, 0, 0, 0, 0, 0},

  {TD_COL_GREY_3, -0x40, -0x49, 0x2F, 3, 2, 6, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x2D, -0x4F, 0x41, 3, 3, 5, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x87, 0x0F, 0x23, 3, 4, 5, 3, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x26, 0x4C, 0x46, 3, 0, 5, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x42, 0x3B, -0x27, 3, 1, 0, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x43, -0x0F, -0x50, 3, 1, 7, 8, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x42, -0x0E, -0x4B, 3, 3, 8, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x46, -0x50, -0x28, 3, 1, 8, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x3A, -0x66, -0x33, 3, 3, 2, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x51, 0x09, -0x43, 3, 4, 3, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x2F, 0x5E, -0x3F, 3, 4, 7, 0, 0, 0, 0, 0, 0},
};


const struct ship_face rock_face[] = {
  {TD_COL_GREY_1, 0x00, 0x00, 0x00, 3, 3, 2, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x00, 0x00, 0x00, 3, 0, 2, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, 0x00, 0x00, 3, 3, 1, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_4, 0x00, 0x00, 0x00, 3, 0, 1, 2, 0, 0, 0, 0, 0},
};

const struct ship_face orbit_face[] = {
  {TD_COL_GREY_1, 0x00, -0x4A, 0x04, 3, 0, 4, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x33, -0x33, 0x17, 3, 1, 4, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x4A, 0x00, 0x04, 3, 1, 5, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x33, 0x33, 0x17, 3, 2, 5, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x4A, 0x04, 3, 2, 6, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x33, 0x33, 0x17, 3, 3, 6, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x4A, 0x00, 0x04, 3, 3, 7, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x33, -0x33, 0x17, 3, 0, 7, 3, 0, 0, 0, 0, 0},

  {TD_COL_GREY_3, 0x00, 0x00, -0x6B, 4, 7, 4, 5, 6, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x6B, 4, 11, 8, 9, 10, 0, 0, 0, 0},

  {TD_COL_GREY_4, -0x37, -0x37, 0x28, 3, 0, 12, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x29, 0x29, 0x5A, 3, 1, 12, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_4, 0x29, 0x29, 0x5A, 3, 2, 12, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x37, -0x37, 0x28, 3, 3, 12, 0, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_1, 0x29, 0x29, 0x5A, 3, 14, 13, 15, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, -0x29, 0x29, 0x5A, 3, 18, 16, 17, 0, 0, 0, 0, 0},
};



/* Two lines on base & detail of IB DB initials added back in :-) */
/* and changed again ... */

const struct ship_face transp_face[] = {
  {TD_COL_GREY_3, 0x00, 0x00, -0x67, 7, 5, 4, 3, 2, 1, 0, 6, 0},

  {TD_COL_BLUE_1, -0x6F, 0x30, -0x07, 4, 9, 8, 1, 2, 0, 0, 0, 0},
  {TD_COL_BLUE_2, -0x69, -0x3F, -0x15, 3, 3, 9, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_4, 0x00, -0x22, 0x00, 6, 14, 13, 9, 3, 4, 10, 0, 0},
  {TD_COL_BLUE_2, 0x69, -0x3F, -0x15, 3, 5, 10, 4, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x6F, 0x30, -0x07, 4, 11, 10, 5, 6, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x08, 0x20, 0x03, 4, 6, 0, 7, 11, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x08, 0x20, 0x03, 4, 8, 7, 0, 1, 0, 0, 0, 0},

  {TD_COL_BLUE_1, -0x4B, 0x20, 0x4F, 4, 13, 12, 8, 9, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x4B, 0x20, 0x4F, 4, 15, 14, 10, 11, 0, 0, 0, 0},

  {TD_COL_GREY_1, -0x08, 0x22, 0x0B, 3, 8, 12, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x08, 0x22, 0x0B, 3, 7, 15, 11, 0, 0, 0, 0, 0},
  {TD_COL_GREY_4, 0x00, 0x26, 0x11, 3, 7, 12, 15, 0, 0, 0, 0, 0},

  {TD_COL_WHITE_2, 0x00, 0x00, 0x79, 4, 15, 12, 13, 14, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x67, 4, 35, 34, 33, 36, 0, 0, 0, 0},

  /* two lines at bottom */
  {TD_COL_WHITE, 0x00, -0x22, 0x00, 2, 30, 29, 31, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x22, 0x00, 2, 31, 32, 29, 0, 0, 0, 0, 0},

  /* single line on top left */
  {TD_COL_WHITE, -0x08, 0x20, 0x03, 2, 17, 16, 18, 0, 0, 0, 0, 0},

  /* two connected triangles on top left */
  {TD_COL_WHITE, -0x08, 0x20, 0x03, 3, 18, 20, 21, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, -0x08, 0x20, 0x03, 3, 20, 19, 21, 0, 0, 0, 0, 0},

  /* a single triangle on the top right */
  {TD_COL_WHITE, 0x08, 0x20, 0x03, 3, 22, 24, 23, 0, 0, 0, 0, 0},

  /* two connected triangles on top right */
  {TD_COL_WHITE, 0x08, 0x20, 0x03, 3, 25, 27, 28, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x08, 0x20, 0x03, 3, 28, 27, 26, 0, 0, 0, 0, 0},
};


const struct ship_face cobra3a_face[] = {
  {TD_COL_GREY_2, 0x00, 0x3E, 0x1F, 3, 1, 0, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, -0x12, 0x37, 0x10, 3, 5, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x12, 0x37, 0x10, 3, 2, 0, 6, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, -0x10, 0x34, 0x0E, 3, 3, 1, 5, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x10, 0x34, 0x0E, 3, 6, 0, 4, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, -0x0E, 0x2F, 0x00, 3, 5, 2, 9, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x0E, 0x2F, 0x00, 3, 9, 2, 6, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_2, -0x3D, 0x66, 0x00, 3, 8, 3, 5, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x3D, 0x66, 0x00, 3, 6, 4, 7, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, 0x00, -0x50, 7, 6, 7, 11, 10, 8, 5, 9, 0},

  {TD_COL_GREY_3, -0x07, -0x2A, 0x09, 4, 10, 1, 3, 8, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, -0x1E, 0x06, 4, 10, 11, 0, 1, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x07, -0x2A, 0x09, 4, 7, 4, 0, 11, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x50, 4, 17, 14, 15, 16, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x50, 4, 19, 12, 13, 18, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x50, 3, 23, 22, 24, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x50, 3, 27, 25, 26, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, 0x3E, 0x1F, 2, 20, 21, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x1E, 0x06, 2, 21, 20, 0, 0, 0, 0, 0, 0},
};

const struct ship_face cobra3b_face[] = {
  {TD_COL_GREY_2, 0x00, 0x3E, 0x1F, 3, 1, 0, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, -0x12, 0x37, 0x10, 3, 5, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, 0x12, 0x37, 0x10, 3, 2, 0, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_3, -0x10, 0x34, 0x0E, 3, 3, 1, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_3, 0x10, 0x34, 0x0E, 3, 6, 0, 4, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, -0x0E, 0x2F, 0x00, 3, 5, 2, 9, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x0E, 0x2F, 0x00, 3, 9, 2, 6, 0, 0, 0, 0, 0},

  {TD_COL_GREEN_2, -0x3D, 0x66, 0x00, 3, 8, 3, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_2, 0x3D, 0x66, 0x00, 3, 6, 4, 7, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, 0x00, -0x50, 7, 6, 7, 11, 10, 8, 5, 9, 0},

  {TD_COL_GREY_3, -0x07, -0x2A, 0x09, 4, 10, 1, 3, 8, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, 0x00, -0x1E, 0x06, 4, 10, 11, 0, 1, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x07, -0x2A, 0x09, 4, 7, 4, 0, 11, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x50, 4, 17, 14, 15, 16, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x50, 4, 19, 12, 13, 18, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x50, 3, 23, 22, 24, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x50, 3, 27, 25, 26, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, 0x3E, 0x1F, 2, 20, 21, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x1E, 0x06, 2, 21, 20, 0, 0, 0, 0, 0, 0},
};


const struct ship_face pythona_face[] = {
  {TD_COL_GREY_2, -0x1B, 0x28, 0x0B, 3, 0, 1, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x1B, 0x28, 0x0B, 3, 2, 1, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x1B, -0x28, 0x0B, 3, 0, 3, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x1B, -0x28, 0x0B, 3, 8, 2, 0, 0, 0, 0, 0, 0},

  {TD_COL_YELLOW_2, -0x13, 0x26, 0x00, 3, 3, 1, 4, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_1, 0x13, 0x26, 0x00, 3, 4, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_1, -0x13, -0x26, 0x00, 3, 3, 9, 8, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, 0x13, -0x26, 0x00, 3, 8, 9, 2, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, -0x19, 0x25, -0x0B, 4, 3, 4, 5, 6, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x19, 0x25, -0x0B, 4, 2, 7, 5, 4, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x19, -0x25, -0x0B, 4, 2, 9, 10, 7, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x19, -0x25, -0x0B, 4, 3, 6, 10, 9, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x70, 4, 10, 6, 5, 7, 0, 0, 0, 0},
};

const struct ship_face pythonb_face[] = {
  {TD_COL_GREY_2, -0x1B, 0x28, 0x0B, 3, 0, 1, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x1B, 0x28, 0x0B, 3, 2, 1, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x1B, -0x28, 0x0B, 3, 0, 3, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x1B, -0x28, 0x0B, 3, 8, 2, 0, 0, 0, 0, 0, 0},

  {TD_COL_GREEN_2, -0x13, 0x26, 0x00, 3, 3, 1, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, 0x13, 0x26, 0x00, 3, 4, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, -0x13, -0x26, 0x00, 3, 3, 9, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_2, 0x13, -0x26, 0x00, 3, 8, 9, 2, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, -0x19, 0x25, -0x0B, 4, 3, 4, 5, 6, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x19, 0x25, -0x0B, 4, 2, 7, 5, 4, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x19, -0x25, -0x0B, 4, 2, 9, 10, 7, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x19, -0x25, -0x0B, 4, 3, 6, 10, 9, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x70, 4, 10, 6, 5, 7, 0, 0, 0, 0},
};


const struct ship_face boa_face[] = {
  {TD_COL_BLUE_4, 0x2B, 0x25, -0x3C, 6, 11, 10, 1, 5, 6, 2, 0, 0},
  {TD_COL_BLUE_2, 0x00, -0x2D, -0x59, 6, 12, 11, 2, 7, 8, 3, 0, 0},
  {TD_COL_BLUE_3, -0x2B, 0x25, -0x3C, 6, 3, 9, 4, 1, 10, 12, 0, 0},

  {TD_COL_BLUE_4, 0x00, 0x28, 0x00, 3, 5, 1, 4, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x3E, -0x20, -0x14, 3, 7, 2, 6, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, -0x3E, -0x20, -0x14, 3, 3, 8, 9, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, 0x17, 0x06, 3, 5, 4, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x17, -0x0F, 0x09, 3, 9, 8, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x17, -0x0F, 0x09, 3, 7, 6, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x1A, 0x0D, 0x0A, 3, 0, 4, 9, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x00, -0x1F, 0x0C, 3, 0, 8, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x1A, 0x0D, 0x0A, 3, 0, 6, 5, 0, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x6B, 3, 12, 10, 11, 0, 0, 0, 0, 0},
};


const struct ship_face anacnda_face[] = {
  {TD_COL_GREEN_1, 0x00, -0x33, -0x31, 5, 3, 2, 1, 0, 4, 0, 0, 0},
  {TD_COL_GREEN_2, -0x33, 0x12, -0x57, 5, 6, 10, 5, 0, 1, 0, 0, 0},
  {TD_COL_GREEN_3, -0x4D, -0x39, -0x13, 5, 7, 11, 6, 1, 2, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, -0x5A, 0x10, 5, 8, 12, 7, 2, 3, 0, 0, 0},

  {TD_COL_GREEN_2, 0x4D, -0x39, -0x13, 5, 9, 13, 8, 3, 4, 0, 0, 0},
  {TD_COL_GREEN_3, 0x33, 0x12, -0x57, 5, 9, 4, 0, 5, 14, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x6F, -0x14, 3, 10, 14, 5, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, -0x61, 0x48, 0x18, 4, 10, 6, 11, 12, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x6C, -0x44, 0x22, 3, 7, 12, 11, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x6C, -0x44, 0x22, 3, 8, 13, 12, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x61, 0x48, 0x18, 4, 9, 14, 12, 13, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x5E, 0x12, 3, 10, 12, 14, 0, 0, 0, 0, 0},
};


const struct ship_face hermit_face[] = {
  {TD_COL_YELLOW_1, 0x09, 0x42, 0x51, 3, 5, 0, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x09, -0x42, 0x51, 3, 2, 5, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x48, 0x40, 0x1F, 3, 6, 0, 1, 0, 0, 0, 0, 0},
  {TD_COL_PINK_1, -0x40, -0x49, 0x2F, 3, 2, 6, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x2D, -0x4F, 0x41, 3, 3, 5, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x87, 0x0F, 0x23, 3, 4, 5, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x26, 0x4C, 0x46, 3, 0, 5, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_1, -0x42, 0x3B, -0x27, 3, 1, 0, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x43, -0x0F, -0x50, 3, 1, 7, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x42, -0x0E, -0x4B, 3, 3, 8, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x46, -0x50, -0x28, 3, 1, 8, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x3A, -0x66, -0x33, 3, 3, 2, 8, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x51, 0x09, -0x43, 3, 4, 3, 7, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x2F, 0x5E, -0x3F, 3, 4, 7, 0, 0, 0, 0, 0, 0},
};


const struct ship_face viper_face[] = {
  {TD_COL_GREY_2, 0x00, 0x20, 0x00, 3, 7, 8, 1, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_3, -0x16, 0x21, 0x0B, 4, 8, 4, 0, 1, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x16, 0x21, 0x0B, 4, 3, 7, 1, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_2, -0x16, -0x21, 0x0B, 4, 2, 0, 4, 6, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x16, -0x21, 0x0B, 4, 0, 2, 5, 3, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, -0x20, 0x00, 3, 2, 6, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x00, -0x30, 6, 4, 8, 7, 3, 5, 6, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x30, 3, 12, 13, 9, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x30, 3, 10, 14, 11, 0, 0, 0, 0, 0},
};



const struct ship_face sidewnd_face[] = {
  {TD_COL_YELLOW_1, 0x00, 0x20, 0x08, 3, 4, 0, 1, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, -0x0C, 0x2F, 0x06, 3, 4, 3, 0, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, 0x0C, 0x2F, 0x06, 3, 2, 4, 1, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, 0x00, -0x70, 4, 2, 5, 3, 4, 0, 0, 0, 0},

  {TD_COL_YELLOW_1, -0x0C, -0x2F, 0x06, 3, 5, 0, 3, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, 0x00, -0x20, 0x08, 3, 1, 0, 5, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_1, 0x0C, -0x2F, 0x06, 3, 2, 1, 5, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x70, 4, 8, 9, 6, 7, 0, 0, 0, 0},
};


const struct ship_face mamba_face[] = {
  {TD_COL_GREEN_1, 0x00, -0x18, 0x02, 3, 1, 4, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_3, 0x00, 0x18, 0x02, 3, 2, 0, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_2, -0x20, 0x40, 0x10, 3, 1, 0, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREEN_2, 0x20, 0x40, 0x10, 3, 3, 0, 4, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, 0x00, -0x7F, 4, 1, 2, 3, 4, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x00, -0x18, 0x02, 3, 11, 12, 9, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x7F, 4, 17, 18, 15, 16, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x00, 0x18, 0x02, 4, 7, 6, 5, 8, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x00, -0x18, 0x02, 3, 13, 14, 10, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x7F, 3, 20, 24, 21, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x00, -0x7F, 3, 22, 23, 19, 0, 0, 0, 0, 0},
};


const struct ship_face krait_face[] = {
  {TD_COL_BLUE_3, 0x03, 0x18, 0x03, 3, 0, 3, 1, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x03, -0x18, 0x03, 3, 2, 3, 0, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_3, -0x03, -0x18, 0x03, 3, 0, 4, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, -0x03, 0x18, 0x03, 3, 1, 4, 0, 0, 0, 0, 0, 0},

  {TD_COL_GREY_3, 0x26, 0x00, -0x4D, 3, 3, 2, 1, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x26, 0x00, -0x4D, 3, 4, 1, 2, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x03, -0x18, 0x03, 2, 3, 5, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x03, 0x18, 0x03, 2, 5, 3, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, -0x03, 0x18, 0x03, 2, 4, 6, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, -0x03, -0x18, 0x03, 2, 6, 4, 0, 0, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x26, 0x00, -0x4D, 3, 12, 11, 13, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, -0x26, 0x00, -0x4D, 3, 16, 14, 15, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x03, 0x18, 0x03, 3, 7, 10, 8, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, -0x03, 0x18, 0x03, 3, 8, 9, 7, 0, 0, 0, 0, 0},
};


const struct ship_face adder_face[] = {
  {TD_COL_GREY_1, 0x00, 0x27, 0x0A, 4, 0, 1, 11, 10, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, -0x27, 0x0A, 4, 1, 0, 12, 13, 0, 0, 0, 0},

  {TD_COL_RED_4, 0x45, 0x32, 0x0D, 3, 2, 11, 1, 0, 0, 0, 0, 0},
  {TD_COL_RED, 0x45, -0x32, 0x0D, 3, 1, 13, 2, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x1E, 0x34, 0x00, 4, 9, 11, 2, 3, 0, 0, 0, 0},
  {TD_COL_RED_3, 0x1E, -0x34, 0x00, 4, 3, 2, 13, 4, 0, 0, 0, 0},

  {TD_COL_DARK_RED, -0x1E, 0x34, 0x00, 4, 10, 8, 6, 7, 0, 0, 0, 0},
  {TD_COL_RED_3, -0x1E, -0x34, 0x00, 4, 7, 6, 5, 12, 0, 0, 0, 0},
  {TD_COL_RED_4, -0x45, 0x32, 0x0D, 3, 10, 7, 0, 0, 0, 0, 0, 0},
  {TD_COL_RED, -0x45, -0x32, 0x0D, 3, 0, 7, 12, 0, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0xA0, 6, 3, 4, 5, 6, 8, 9, 0, 0},
  {TD_COL_GREY_2, 0x00, 0x1C, 0x00, 4, 10, 11, 9, 8, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x00, -0x1C, 0x00, 4, 5, 4, 13, 12, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x00, 0x27, 0x0A, 4, 17, 14, 15, 16, 0, 0, 0, 0},
};


const struct ship_face gecko_face[] = {
  {TD_COL_GREY_2, 0x00, 0x1F, 0x05, 4, 3, 2, 0, 1, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x04, 0x2D, 0x08, 3, 3, 1, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x19, -0x6C, 0x13, 3, 5, 1, 7, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, -0x54, 0x0C, 4, 1, 0, 6, 7, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x19, -0x6C, 0x13, 3, 4, 6, 0, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x04, 0x2D, 0x08, 3, 0, 2, 4, 0, 0, 0, 0, 0},

  {TD_COL_GREEN_2, -0x58, 0x10, -0xD6, 3, 4, 2, 6, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0xBB, 4, 2, 3, 7, 6, 0, 0, 0, 0},
  {TD_COL_GREEN_2, 0x58, 0x10, -0xD6, 3, 5, 7, 3, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, -0x54, 0x0C, 2, 8, 10, 9, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x54, 0x0C, 2, 11, 9, 8, 0, 0, 0, 0, 0},
};



const struct ship_face cobra1_face[] = {
  {TD_COL_BLUE_2, 0x00, 0x29, 0x0A, 3, 0, 1, 8, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x00, -0x1B, 0x03, 4, 6, 7, 1, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_3, -0x08, 0x2E, 0x08, 4, 2, 0, 8, 4, 0, 0, 0, 0},
  {TD_COL_BLUE_4, -0x0C, -0x39, 0x0C, 3, 6, 0, 2, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x08, 0x2E, 0x08, 4, 1, 3, 5, 8, 0, 0, 0, 0},
  {TD_COL_BLUE_4, 0x0C, -0x39, 0x0C, 3, 1, 7, 3, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_2, 0x00, 0x31, 0x00, 3, 4, 8, 5, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x9A, 4, 7, 6, 4, 5, 0, 0, 0, 0},

  {TD_COL_BLUE_2, -0x79, 0x6F, -0x3E, 3, 2, 4, 6, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x79, 0x6F, -0x3E, 3, 3, 7, 5, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, 0x29, 0x0A, 2, 9, 10, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x1B, 0x03, 2, 10, 9, 0, 0, 0, 0, 0, 0},
};


const struct ship_face worm_face[] = {
  {TD_COL_GREY_4, 0x00, 0x58, 0x46, 4, 1, 0, 2, 3, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x46, 0x42, 0x23, 3, 0, 4, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x46, 0x42, 0x23, 3, 1, 3, 5, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x40, 0x31, 0x0E, 4, 2, 4, 6, 8, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x40, 0x31, 0x0E, 4, 5, 3, 9, 7, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0xC8, 4, 6, 7, 9, 8, 0, 0, 0, 0},

  {TD_COL_GREY_3, 0x00, -0x50, 0x00, 6, 4, 0, 1, 5, 7, 6, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x45, 0x0E, 4, 9, 3, 2, 8, 0, 0, 0, 0},
};


const struct ship_face asp2_face[] = {
  {TD_COL_GREY_4, 0x00, -0x23, 0x05, 5, 8, 9, 7, 0, 4, 0, 0, 0},
  {TD_COL_GREY_2, 0x08, -0x26, -0x07, 5, 3, 4, 0, 1, 2, 0, 0, 0},
  {TD_COL_GREY_1, -0x08, -0x26, -0x07, 5, 1, 0, 7, 6, 5, 0, 0, 0},
  {TD_COL_GREY_3, 0x3B, -0x40, 0x1F, 3, 8, 4, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, -0x3B, -0x40, 0x1F, 3, 6, 7, 9, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_2, 0x00, 0x18, -0x01, 3, 11, 10, 12, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x00, 0x2B, 0x13, 4, 9, 8, 10, 11, 0, 0, 0, 0},
  {TD_COL_BLUE_4, -0x06, 0x1C, -0x02, 4, 6, 11, 12, 5, 0, 0, 0, 0},
  {TD_COL_BLUE_4, 0x06, 0x1C, -0x02, 4, 2, 12, 10, 3, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x50, 0x2E, 0x32, 3, 3, 10, 8, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, -0x50, 0x2E, 0x32, 3, 9, 11, 6, 0, 0, 0, 0, 0},

  {TD_COL_DARK_RED, 0x00, 0x00, -0x5A, 4, 2, 1, 5, 12, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, 0x00, -0x5A, 4, 14, 15, 13, 16, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, 0x2B, 0x13, 2, 18, 17, 0, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, -0x23, 0x05, 2, 17, 18, 0, 0, 0, 0, 0, 0},
};


const struct ship_face ferdlce_face[] = {
  {TD_COL_GREY_1, 0x00, 0x18, 0x06, 4, 5, 0, 8, 9, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x44, 0x00, 0x18, 3, 0, 5, 1, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_2, -0x3F, 0x00, -0x25, 4, 2, 1, 5, 6, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0x68, 4, 3, 2, 6, 7, 0, 0, 0, 0},

  {TD_COL_BLUE_2, 0x3F, 0x00, -0x25, 4, 4, 3, 7, 8, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x44, 0x00, 0x18, 3, 4, 8, 0, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_3, -0x0C, 0x2E, -0x13, 3, 5, 9, 6, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x00, 0x2D, -0x16, 3, 6, 9, 7, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x0C, 0x2E, -0x13, 3, 7, 9, 8, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, -0x1C, 0x00, 5, 4, 0, 1, 2, 3, 0, 0, 0},

  {TD_COL_DARK_RED, 0x00, -0x1C, 0x00, 3, 16, 18, 17, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x18, 0x06, 3, 11, 10, 12, 0, 0, 0, 0, 0},
  {TD_COL_DARK_RED, 0x00, 0x18, 0x06, 3, 15, 13, 14, 0, 0, 0, 0, 0},
};


const struct ship_face moray_face[] = {
  {TD_COL_BLUE_4, 0x00, 0x2B, 0x07, 3, 0, 2, 1, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, -0x0A, 0x31, 0x07, 3, 1, 2, 3, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_3, 0x0A, 0x31, 0x07, 3, 4, 2, 0, 0, 0, 0, 0, 0},

  {TD_COL_GREY_1, -0x3B, -0x1C, -0x65, 3, 3, 2, 6, 0, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, -0x34, -0x4E, 3, 6, 2, 5, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x3B, -0x1C, -0x65, 3, 5, 2, 4, 0, 0, 0, 0, 0},

  {TD_COL_BLUE_1, -0x48, -0x63, 0x32, 3, 6, 1, 3, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2, 0x00, -0x53, 0x1E, 4, 6, 5, 0, 1, 0, 0, 0, 0},
  {TD_COL_BLUE_1, 0x48, -0x63, 0x32, 3, 4, 0, 5, 0, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, -0x34, -0x4E, 3, 8, 9, 7, 0, 0, 0, 0, 0},

  {TD_COL_WHITE, 0x00, 0x2B, 0x07, 2, 11, 10, 12, 0, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x00, 0x2B, 0x07, 2, 12, 13, 10, 0, 0, 0, 0, 0},
};


const struct ship_face thargoid_face[] = {
  {TD_COL_PINK_1, 0x67, -0x3C, 0x19, 4, 1, 0, 8, 9, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x67, -0x3C, -0x19, 4, 2, 1, 9, 10, 0, 0, 0, 0},
  {TD_COL_PINK_1, 0x67, -0x19, -0x3C, 4, 3, 2, 10, 11, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x67, 0x19, -0x3C, 4, 4, 3, 11, 12, 0, 0, 0, 0},

  /* top plane */
  {TD_COL_GREY_3, 0x40, 0x00, 0x00, 8, 0, 1, 2, 3, 4, 5, 6, 7},

  {TD_COL_PINK_1, 0x67, 0x3C, -0x19, 4, 5, 4, 12, 13, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x67, 0x3C, 0x19, 4, 6, 5, 13, 14, 0, 0, 0, 0},
  {TD_COL_PINK_1, 0x67, 0x19, 0x3C, 4, 7, 6, 14, 15, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x67, -0x19, 0x3C, 4, 0, 7, 15, 8, 0, 0, 0, 0},

  /* bottom plane */
  {TD_COL_GREY_3, -0x30, 0x00, 0x00, 8, 15, 14, 13, 12, 11, 10, 9, 8},

  /* two red triangles */
  {TD_COL_ENGINE, -0x30, 0x00, 0x00, 3, 16, 17, 18, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, -0x30, 0x00, 0x00, 3, 19, 20, 21, 0, 0, 0, 0, 0},
};


const struct ship_face thargon_face[] = {
  {TD_COL_ENGINE, -0x24, 0x00, 0x00, 5, 3, 2, 1, 0, 4, 0, 0, 0},

  {TD_COL_GREY_1, 0x14, -0x05, 0x07, 4, 6, 5, 0, 1, 0, 0, 0, 0},
  {TD_COL_WHITE, 0x2E, -0x2A, -0x0E, 4, 7, 6, 1, 2, 0, 0, 0, 0},
  {TD_COL_PINK_1, 0x24, 0x00, -0x68, 4, 8, 7, 2, 3, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x2E, 0x2A, -0x0E, 4, 9, 8, 3, 4, 0, 0, 0, 0},
  {TD_COL_PINK_1, 0x14, 0x05, 0x07, 4, 4, 0, 5, 9, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x24, 0x00, 0x00, 5, 9, 5, 6, 7, 8, 0, 0, 0},
};


const struct ship_face constrct_face[] = {
  {TD_COL_GREY_4, 0x00, 0x37, 0x0F, 4, 1, 0, 8, 9, 0, 0, 0, 0},
  {TD_COL_GREY_1, -0x18, 0x4B, 0x14, 3, 1, 9, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x18, 0x4B, 0x14, 3, 0, 7, 8, 0, 0, 0, 0, 0},

  {TD_COL_YELLOW_2, 0x2C, 0x4B, 0x00, 3, 7, 6, 8, 0, 0, 0, 0, 0},
  {TD_COL_YELLOW_2, -0x2C, 0x4B, 0x00, 3, 9, 3, 2, 0, 0, 0, 0, 0},

  {TD_COL_YELLOW_1, -0x2C, 0x4B, 0x00, 3, 9, 4, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_1, 0x00, 0x35, 0x00, 4, 8, 5, 4, 9, 0, 0, 0, 0},
  {TD_COL_YELLOW_1, 0x2C, 0x4B, 0x00, 3, 8, 6, 5, 0, 0, 0, 0, 0},

  {TD_COL_GREY_2, 0x00, 0x00, -0xA0, 4, 6, 3, 4, 5, 0, 0, 0, 0},
  {TD_COL_GREY_3, 0x00, -0x1B, 0x00, 6, 3, 6, 7, 0, 1, 2, 0, 0},
  {TD_COL_ENGINE, 0x00, -0x1B, 0x00, 3, 12, 10, 14, 0, 0, 0, 0, 0},
  {TD_COL_ENGINE, 0x00, -0x1B, 0x00, 3, 15, 11, 13, 0, 0, 0, 0, 0},
};

const struct ship_face cougar_face[] = {
  {TD_COL_GREY_1, -0x10, 0x2E, 0x04, 4, 2, 1, 0, 3, 0, 0, 0, 0},
  {TD_COL_GREY_2, -0x10, -0x2E, 0x04, 3, 4, 1, 2, 0, 0, 0, 0, 0},
  {TD_COL_GREY_4, 0x00, -0x1B, 0x05, 4, 4, 5, 0, 1, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x10, -0x2E, 0x04, 3, 6, 5, 4, 0, 0, 0, 0, 0},
  {TD_COL_GREY_2, 0x10, 0x2E, 0x04, 4, 5, 6, 3, 0, 0, 0, 0, 0},
  {TD_COL_GREY_4, 0x00, 0x00, -0xA0, 4, 6, 4, 2, 3, 0, 0, 0, 0},

  {TD_COL_YELLOW_1, -0x10,-0x2E, 0x04, 4, 1, 2, 8, 7, 0, 0, 0, 0},
  {TD_COL_YELLOW_1, -0x10, 0x2E, 0x04, 4, 7, 8, 2, 1, 0, 0, 0, 0},
  {TD_COL_YELLOW_1,  0x10, 0x2E, 0x04, 4, 5, 6,10, 9, 0, 0, 0, 0},
  {TD_COL_YELLOW_1,  0x10,-0x2E, 0x04, 4, 9,10, 6, 5, 0, 0, 0, 0},

  {TD_COL_BLUE_3,   -0x10, 0x2E, 0x04, 3, 12, 13, 11, 0, 0, 0, 0, 0},
  {TD_COL_BLUE_2,    0x10, 0x2E, 0x04, 3, 11, 14, 12, 0, 0, 0, 0, 0},

  {TD_COL_ENGINE, 0x00, 0x00, -0xA0, 4, 15, 18, 17, 16, 0, 0, 0, 0},
};

const struct ship_face dodec_face[] = {
  {TD_COL_GREY_1, 0x00, 0x00, 0xC4, 5, 3, 2, 1, 0, 4, 0, 0, 0},

  {TD_COL_GREY_2, 0x67, 0x8E, 0x58, 5, 6, 10, 5, 0, 1, 0, 0, 0},
  {TD_COL_GREY_3, 0xA9, -0x37, 0x59, 5, 7, 11, 6, 1, 2, 0, 0, 0},
  {TD_COL_GREY_4, 0x00, -0xB0, 0x58, 5, 8, 12, 7, 2, 3, 0, 0, 0},
  {TD_COL_GREY_5, -0xA9, -0x37, 0x59, 5, 9, 13, 8, 3, 4, 0, 0, 0},
  {TD_COL_GREY_4, -0x67, 0x8E, 0x58, 5, 5, 14, 9, 4, 0, 0, 0, 0},

  {TD_COL_GREY_3, 0x00, 0xB0, -0x58, 5, 15, 19, 14, 5, 10, 0, 0, 0},
  {TD_COL_GREY_4, 0xA9, 0x37, -0x59, 5, 16, 15, 10, 6, 11, 0, 0, 0},
  {TD_COL_GREY_5, 0x67, -0x8E, -0x58, 5, 17, 16, 11, 7, 12, 0, 0, 0},
  {TD_COL_GREY_4, -0x67, -0x8E, -0x58, 5, 18, 17, 12, 8, 13, 0, 0, 0},
  {TD_COL_GREY_2, -0xA9, 0x37, -0x59, 5, 19, 18, 13, 9, 14, 0, 0, 0},

  {TD_COL_GREY_1, 0x00, 0x00, -0xC4, 5, 19, 15, 16, 17, 18, 0, 0, 0},

  {TD_COL_BLACK, 0x00, 0x00, 0xC4, 4, 22, 20, 21, 23, 0, 0, 0, 0},
};

const struct ship_face *ship_face_list[NO_OF_SHIPS] = {
  missile_face, coriolis_face, esccaps_face, alloy_face,
  cargo_face, boulder_face, asteroid_face, rock_face,
  orbit_face, transp_face, cobra3a_face, pythona_face,
  boa_face, anacnda_face, hermit_face, viper_face,
  sidewnd_face, mamba_face, krait_face, adder_face,
  gecko_face, cobra1_face, worm_face,  moray_face,
  cobra3b_face, asp2_face, pythonb_face, ferdlce_face,
  thargoid_face, thargon_face, constrct_face, cougar_face,
  dodec_face
};

const struct ship_data *ship_data_list[NO_OF_SHIPS] = {
  &missile_data, &coriolis_data, &esccaps_data, &alloy_data,
  &cargo_data, &boulder_data, &asteroid_data, &rock_data,
  &orbit_data, &transp_data, &cobra3a_data, &pythona_data,
  &boa_data, &anacnda_data, &hermit_data, &viper_data,
  &sidewnd_data, &mamba_data, &krait_data, &adder_data,
  &gecko_data, &cobra1_data, &worm_data, &moray_data,
  &cobra3b_data, &asp2_data, &pythonb_data, &ferdlce_data,
  &thargoid_data, &thargon_data, &constrct_data, &cougar_data,
  &dodec_data
};

const struct ship_point *ship_point_list[NO_OF_SHIPS] = {
  missile_point, coriolis_point, esccaps_point, alloy_point,
  cargo_point, boulder_point, asteroid_point, rock_point,
  orbit_point, transp_point, cobra3a_point, pythona_point,
  boa_point, anacnda_point, hermit_point, viper_point,
  sidewnd_point, mamba_point, krait_point, adder_point,
  gecko_point, cobra1_point, worm_point, moray_point,
  cobra3b_point, asp2_point, pythonb_point, ferdlce_point,
  thargoid_point, thargon_point, constrct_point, cougar_point,
  dodec_point
};

main (void)
{
  char name[32];
  FILE *file;
  int i, j, d, dmax;
  struct ship_data ship;
  Int16 *p;
  Int8 data[16];
  int max_faces = 0, max_points = 0;
  int max_edges = 0;

  for (i = 0; i < NO_OF_SHIPS; i++) {

    sprintf (name, "ship%04x.bin", i);
    printf ("writing %s (%s)\n", name, ship_data_list[i]->name);

    file = fopen (name, "wb");
    if (file == NULL) {
      printf ("error opening file");
      return 1;
    }

    memcpy (&ship, ship_data_list[i], sizeof (struct ship_data));

    if (ship.num_points > max_points)
      max_points = ship.num_points;
    if (ship.num_faces > max_faces)
      max_faces = ship.num_faces;

    /* get diameter of thingy */
    dmax = 0;
    for (p =(Int16*)ship_point_list[i],j = 0; j < ship.num_points; j++,p+=8) {
      d = (int)sqrt(p[0]*p[0] + p[1]*p[1] + p[2]*p[2]);
      if(d > dmax) dmax = d;
    }

//    printf("dist = %d (%d), factor = %d\n", dmax, ship.size, ship.size/dmax);

    /* override size with calculated value */
    ship.size = dmax;

    /* convert to little endian */
    ship.size = htons (ship.size);
    ship.bounty = htons (ship.bounty);

    fwrite (&ship, sizeof (ship), 1l, file);

    /* write points */
    for (p = (Int16 *) ship_point_list[i], j = 0; j < ship.num_points; j++) {
      data[0] = *p++ / 2;	// x
      data[1] = *p++ / 2;	// y
      data[2] = *p++ / 2;	// z
      data[3] = *p++;		// dist
      data[4] = *p++;		// face1
      data[5] = *p++;		// face2
      data[6] = *p++;		// face3 
      data[7] = *p++;		// face4
      fwrite (data, sizeof (struct ship_point) / 2, 1l, file);
    }

    /* write faces */
    for (p = (Int16 *) ship_face_list[i], j = 0; j < ship.num_faces; j++) {
      if (max_edges < ship_face_list[i][j].points)
	max_edges = ship_face_list[i][j].points;
      data[0] = *p++;		// colour
      p += 3;			// skip norm_x, norm_y, norm_z
      data[1] = *p++;		// points
      data[2] = *p++;		// p1
      data[3] = *p++;		// p2
      data[4] = *p++;		// p3
      data[5] = *p++;		// p4
      data[6] = *p++;		// p5
      data[7] = *p++;		// p6
      data[8] = *p++;		// p7
      data[9] = *p++;		// p8
      fwrite (data, 10l, 1l, file);
    }

    fclose (file);
  }

  printf ("writing 3d_limit.h\n");
  file = fopen ("3d_limit.h", "w");
  if (file == NULL) {
    printf ("error opening file");
    return 1;
  }

  fprintf (file, "#define MAX_POINTS %d\n", max_points);
  fprintf (file, "#define MAX_FACES %d\n", max_faces);
  fprintf (file, "#define MAX_EDGES %d\n", max_edges);

  fclose (file);

  return 0;
}
